package org.apache.ctakes.gui.pipeline;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author SPF , chip-nlp
 * @version %I%
 * @since 1/13/2017
 */
public class PiperDisplayModel {

   static private final Logger LOGGER = LoggerFactory.getLogger( "PiperDisplayModel" );
}
